package VMOMI::HostIncompatibleForRecordReplayReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
